# homespeaker
Code to turn a laptop into a home speaker.

## Functionality

Currently only supports scheduling "waking the screen" and "playing an alarm."  The voice interface does not yet exist, it depends on a config file to exist.
